==> zio-aws-dataexchange_2.13-5.17.129.2-sources.jar: zio/aws/dataexchange/model/GetEventActionRequest.scala <==
package zio.aws.dataexchange.model
import zio.aws.dataexchange.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class GetEventActionRequest(eventActionId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dataexchange.model.GetEventActionRequest = {
    import GetEventActionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dataexchange.model.GetEventActionRequest
      .builder()
      .eventActionId(__string.unwrap(eventActionId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.dataexchange.model.GetEventActionRequest.ReadOnly =
    zio.aws.dataexchange.model.GetEventActionRequest.wrap(buildAwsValue())
}
object GetEventActionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dataexchange.model.GetEventActionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dataexchange.model.GetEventActionRequest =
      zio.aws.dataexchange.model.GetEventActionRequest(eventActionId)
    def eventActionId: __string
    def getEventActionId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(eventActionId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dataexchange.model.GetEventActionRequest
  ) extends zio.aws.dataexchange.model.GetEventActionRequest.ReadOnly {
    override val eventActionId: __string =
      zio.aws.dataexchange.model.primitives.__string(impl.eventActionId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.dataexchange.model.GetEventActionRequest
  ): zio.aws.dataexchange.model.GetEventActionRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-dataexchange_2.13-5.17.155.1-sources.jar: zio/aws/dataexchange/model/GetEventActionRequest.scala <==
package zio.aws.dataexchange.model
import zio.aws.dataexchange.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class GetEventActionRequest(eventActionId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dataexchange.model.GetEventActionRequest = {
    import GetEventActionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dataexchange.model.GetEventActionRequest
      .builder()
      .eventActionId(eventActionId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.dataexchange.model.GetEventActionRequest.ReadOnly =
    zio.aws.dataexchange.model.GetEventActionRequest.wrap(buildAwsValue())
}
object GetEventActionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dataexchange.model.GetEventActionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dataexchange.model.GetEventActionRequest =
      zio.aws.dataexchange.model.GetEventActionRequest(eventActionId)
    def eventActionId: __string
    def getEventActionId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(eventActionId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dataexchange.model.GetEventActionRequest
  ) extends zio.aws.dataexchange.model.GetEventActionRequest.ReadOnly {
    override val eventActionId: __string = impl.eventActionId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.dataexchange.model.GetEventActionRequest
  ): zio.aws.dataexchange.model.GetEventActionRequest.ReadOnly = new Wrapper(
    impl
  )
}
